@@ -248,7 +248,7 @@ void MainWindow::getMusicStream() {
 
     m_stream = Music::getMusicStream(QUrl::fromUserInput(m_paramsEdit->text().section(',', 0, 0).trimmed()), m_paramsEdit->text().section(',', -1).trimmed());
     this->connect(m_cancelButton, SIGNAL(clicked()), this, SLOT(stop()));
-    this->connect(m_stream, SIGNAL(statusChanged(StreamStatus::Status)), this, SLOT(onMusicStreamStatusChanged(StreamStatus::Status)));
+    this->connect(m_stream, SIGNAL(statusChanged(MusicStream::Status)), this, SLOT(onMusicMusicStreamChanged(MusicStream::Status)));
 
     m_stream->start();
 }
@@ -259,7 +259,7 @@ void MainWindow::onArtistsReady(ArtistList *artists) {
     m_resultEdit->clear();
 
     switch (artists->error()) {
-    case ReplyError::NoError:
+    case ArtistList::NoError:
         foreach (Artist *artist, artists->artists()) {
             m_resultEdit->append(tr("Id: %1").arg(artist->id()));
             m_resultEdit->append(tr("Name: %1").arg(artist->name()));
@@ -295,7 +295,7 @@ void MainWindow::onAlbumsReady(AlbumList *albums) {
     m_resultEdit->clear();
 
     switch (albums->error()) {
-    case ReplyError::NoError:
+    case AlbumList::NoError:
         foreach (Album *album, albums->albums()) {
             m_resultEdit->append(tr("Id: %1").arg(album->id()));
             m_resultEdit->append(tr("Title: %1").arg(album->title()));
@@ -332,7 +332,7 @@ void MainWindow::onPlaylistReady(Playlist *playlist) {
     m_resultEdit->clear();
 
     switch (playlist->error()) {
-    case ReplyError::NoError:
+    case Playlist::NoError:
         m_resultEdit->append(tr("Id: %1").arg(playlist->id()));
         m_resultEdit->append(tr("Name: %1").arg(playlist->name()));
         m_resultEdit->append(tr("Url: %1").arg(playlist->url().toString()));
@@ -359,7 +359,7 @@ void MainWindow::onPlaylistsReady(PlaylistList *playlists) {
     m_resultEdit->clear();
 
     switch (playlists->error()) {
-    case ReplyError::NoError:
+    case PlaylistList::NoError:
         foreach (Playlist *playlist, playlists->playlists()) {
             m_resultEdit->append(tr("Id: %1").arg(playlist->id()));
             m_resultEdit->append(tr("Name: %1").arg(playlist->name()));
@@ -392,7 +392,7 @@ void MainWindow::onSongsReady(SongList *songs) {
     m_resultEdit->clear();
 
     switch (songs->error()) {
-    case ReplyError::NoError:
+    case SongList::NoError:
         foreach (Song *song, songs->songs()) {
             m_resultEdit->append(tr("Id: %1").arg(song->id()));
             m_resultEdit->append(tr("Title: %1").arg(song->title()));
@@ -442,7 +442,7 @@ void MainWindow::onReplyFinished(Reply *reply) {
     m_resultEdit->append(tr("Status: %1").arg(reply->status()));
 
     switch (reply->error()) {
-    case ReplyError::NoError:
+    case Reply::NoError:
         m_resultEdit->append(reply->resultString());
         break;
     default:
@@ -466,7 +466,7 @@ void MainWindow::onArtworkReady(Artwork *artwork) {
     m_resultEdit->clear();
 
     switch (artwork->error()) {
-    case ReplyError::NoError:
+    case Artwork::NoError:
         m_artworkLabel->setPixmap(QPixmap::fromImage(artwork->image()));
         m_resultEdit->append(tr("Artwork loaded from Url: %1").arg(artwork->url().toString()));
         break;
@@ -485,17 +485,17 @@ void MainWindow::onArtworkCancelled(Artwork *artwork) {
     artwork->deleteLater();
 }
 
-void MainWindow::onMusicStreamStatusChanged(StreamStatus::Status status) {
+void MainWindow::onMusicStreamStatusChanged(MusicStream::Status status) {
     switch (status) {
-    case StreamStatus::Ready:
+    case MusicStream::Ready:
         m_playPauseButton->setEnabled(true);
         m_stopButton->setEnabled(true);
         m_slider->setEnabled(true);
         return;
-    case StreamStatus::Finished:
+    case MusicStream::Finished:
         m_resultEdit->append(tr("Music stream finished. Size: %1").arg(m_stream->streamPosition()));
         return;
-    case StreamStatus::Error:
+    case MusicStream::Failed:
         m_resultEdit->append(tr("Music stream error. Error: %1").arg(m_stream->errorString()));
         return;
     default:
@@ -547,7 +547,7 @@ void MainWindow::togglePlayPause() {
         m_mediaPlayer->setMedia(QMediaContent(), m_stream);
 
         switch (m_stream->status()) {
-        case StreamStatus::Stopped:
+        case MusicStream::Stopped:
             m_stream->start();
             break;
         default:
