@@ -220,7 +220,7 @@ Node* Files::setFilePublic(const QString &resourcePath, bool isPublic) {
  */
 FileTransfer* Files::uploadFile(const QString &filePath, const QString &contentType, const QString &contentPath, bool isPublic) {
     FileTransfer *transfer = new FileTransfer;
-    transfer->setTransferType(TransferType::Upload);
+    transfer->setTransferType(FileTransfer::Upload);
     transfer->setFilePath(filePath);
     transfer->setContentType(contentType.isEmpty() ? "application/octet-stream" : contentType);
     transfer->setContentPath(contentPath);
@@ -235,7 +235,7 @@ FileTransfer* Files::uploadFile(const QString &filePath, const QString &contentT
  */
 FileTransfer* Files::downloadFile(const QString &contentPath, const QString &localPath, bool overwriteExistingFile) {
     FileTransfer *transfer = new FileTransfer;
-    transfer->setTransferType(TransferType::Download);
+    transfer->setTransferType(FileTransfer::Download);
     transfer->setContentPath(contentPath);
     transfer->setFilePath(localPath);
     transfer->setOverwriteExistingFile(overwriteExistingFile);
