@@ -18,10 +18,12 @@
 #ifndef QUBUNTUONE_GLOBAL_H
 #define QUBUNTUONE_GLOBAL_H
 
-#include <QtCore/qglobal.h>
+#include <qglobal.h>
 
 #if defined(QUBUNTUONE_LIBRARY)
 #  define QUBUNTUONESHARED_EXPORT Q_DECL_EXPORT
+#elif defined(QUBUNTUONE_STATIC_LIBRARY)
+# define QUBUNTUONESHARED_EXPORT
 #else
 #  define QUBUNTUONESHARED_EXPORT Q_DECL_IMPORT
 #endif
